@@ -11,6 +11,9 @@
 #' it is set equal to \code{df.residual} of model \code{fit1}. If that cannot
 #' be done, the procedure assumes (perhaps incorrectly) a large sample.
 #' @param df.com Deprecated
+#' @note Warning: `D1()` assumes that the order of the variables is the
+#' same in different models. See
+#' \url{https://github.com/amices/mice/issues/420} for details.
 #' @references
 #' Li, K. H., T. E. Raghunathan, and D. B. Rubin. 1991.
 #' Large-Sample Significance Levels from Multiply Imputed Data Using
@@ -44,7 +47,8 @@ D1 <- function(fit1, fit0 = NULL, dfcom = NULL, df.com = NULL) {
     dfcom <- df.com
   }
 
-  dfcom <- get.dfcom(fit1, dfcom)
+  model <- getfit(fit1, 1L)
+  dfcom <- get.dfcom(model, dfcom)
 
   # fit1: a fitlist or mira-object
   # fit0: named numerical vector, character vector, or list
@@ -58,8 +62,7 @@ D1 <- function(fit1, fit0 = NULL, dfcom = NULL, df.com = NULL) {
     names(beta) <- names(qbar1)
     fit0 <- lapply(fit1, fix.coef, beta = beta)
     fit0 <- as.mitml.result(fit0)
-  }
-  else if (is.mira(fit0)) {
+  } else if (is.mira(fit0)) {
     fit0 <- as.mitml.result(fit0)
   }
 
