@@ -40,8 +40,6 @@
 #' mechanisms: the missingness depends completely on chance (MCAR), the missingness
 #' depends on the values of the observed variables (i.e. the variables that remain
 #' complete) (MAR) or on the values of the variables that will be made incomplete (MNAR).
-#' For a discussion on how missingness mechanisms are related to the observed data,
-#' we refer to \doi{10.1177/0049124118799376}{Schouten and Vink, 2018}.
 #'
 #' When the user specifies the missingness mechanism to be \code{"MCAR"}, the candidates
 #' have an equal probability of becoming incomplete. For a \code{"MAR"} or \code{"MNAR"} mechanism,
@@ -82,11 +80,9 @@
 #' The continuous distributions of probabilities are based on the logistic distribution function.
 #' The user can specify the type of missingness, which, again, may differ between patterns.
 #'
-#' For an example and more explanation about how the arguments interact with each other,
-#' we refer to the vignette
-#' \href{https://rianneschouten.github.io/mice_ampute/vignette/ampute.html}{Generate missing values with ampute}
-#' The amputation methodology is published in
-#' \doi{10.1080/00949655.2018.1491577}{Schouten, Lugtig and Vink, 2018}.
+#' For an example and more explanation about how the arguments interact with
+#' each other, we refer to the vignette:
+#' \href{https://rianneschouten.github.io/mice_ampute/vignette/ampute.html}{Generate missing values with ampute}.
 #'
 #' @param data A complete data matrix or data frame. Values should be numeric.
 #' Categorical variables should have been transformed to dummies.
@@ -150,31 +146,35 @@
 #' @param run Logical. If TRUE, the amputations are implemented. If FALSE, the
 #' return object will contain everything except for the amputed data set.
 #'
-#' @return Returns an S3 object of class \code{\link{mads-class}} (multivariate
+#' @return Returns an S3 object of class \code{\link{mads}} (multivariate
 #' amputed data set)
 #' @author Rianne Schouten [aut, cre], Gerko Vink [aut], Peter Lugtig [ctb], 2016
-#' @seealso \code{\link{mads-class}}, \code{\link{bwplot}}, \code{\link{xyplot}},
-#' \code{\link{mice}}
+#' @seealso \code{\link{mads}}, \code{\link{bwplot.mads}},
+#' \code{\link{xyplot.mads}}
 #'
-#' @references Brand, J.P.L. (1999) \emph{Development, implementation and
+#' @references
+#' Brand, J.P.L. (1999) \emph{Development, implementation and
 #' evaluation of multiple imputation strategies for the statistical analysis of
 #' incomplete data sets.} pp. 110-113. Dissertation. Rotterdam: Erasmus University.
 #'
 #' Schouten, R.M., Lugtig, P and Vink, G. (2018)
-#' {Generating missing values for simulation purposes: A multivariate amputation procedure.}.
+#' Generating missing values for simulation purposes: A multivariate
+#' amputation procedure.
 #' \emph{Journal of Statistical Computation and Simulation}, 88(15): 1909-1930.
 #' \doi{10.1080/00949655.2018.1491577}
 #'
-#' Schouten, R.M. and Vink, G. (2018){The Dance of the Mechanisms: How Observed Information Influences the Validity of Missingness Assumptions}.
+#' Schouten, R.M. and Vink, G. (2018) The Dance of the Mechanisms: How Observed
+#' Information Influences the Validity of Missingness Assumptions.
 #' \emph{Sociological Methods and Research}, 50(3): 1243-1258.
 #' \doi{10.1177/0049124118799376}
 #'
 #' Van Buuren, S., Brand, J.P.L., Groothuis-Oudshoorn, C.G.M., Rubin, D.B. (2006)
-#' {Fully conditional specification in multivariate imputation.}
+#' Fully conditional specification in multivariate imputation.
 #' \emph{Journal of Statistical Computation and Simulation}, 76(12): 1049-1064.
 #' \doi{10.1080/10629360600810434}
 #'
-#' Van Buuren, S. (2018) \href{https://stefvanbuuren.name/fimd/sec-FCS.html#sec:MICE}{\emph{Flexible Imputation of Missing Data. Second Edition.}}
+#' Van Buuren, S. (2018).
+#' \emph{Flexible Imputation of Missing Data. Second Edition.}
 #' Chapman & Hall/CRC. Boca Raton, FL.
 #'
 #' Vink, G. (2016) Towards a standardized evaluation of multiple imputation routines.
@@ -208,6 +208,7 @@ ampute <- function(data, prop = 0.5, patterns = NULL, freq = NULL,
   if (is.null(data)) {
     stop("Argument data is missing, with no default", call. = FALSE)
   }
+  data.in <- data # preserve an original set to inject the NA's in later
   data <- check.dataform(data)
   if (anyNA(data)) {
     stop("Data cannot contain NAs", call. = FALSE)
@@ -218,7 +219,7 @@ ampute <- function(data, prop = 0.5, patterns = NULL, freq = NULL,
   data <- data.frame(data)
   if (any(vapply(data, Negate(is.numeric), logical(1))) && mech != "MCAR") {
     data <- as.data.frame(sapply(data, as.numeric))
-    warning("Data is made numeric because the calculation of weights requires numeric data",
+    warning("Data is made numeric internally, because the calculation of weights requires numeric data",
       call. = FALSE
     )
   }
@@ -449,13 +450,13 @@ ampute <- function(data, prop = 0.5, patterns = NULL, freq = NULL,
       }
     }
   }
-  #
+
   # Create return object
   names(patterns.new) <- names(data)
   names(weights) <- names(data)
   call <- match.call()
-  missing.data <- data.frame(missing.data)
-  result <- list(
+  data.in[is.na(data.frame(missing.data))] <- NA
+  result <- mads(
     call = call,
     prop = prop,
     patterns = patterns.new,
@@ -463,18 +464,13 @@ ampute <- function(data, prop = 0.5, patterns = NULL, freq = NULL,
     mech = mech,
     weights = weights,
     cont = cont,
-    std = std,
     type = type,
     odds = odds,
-    amp = missing.data,
+    amp = data.in,
     cand = P - 1,
     scores = scores,
-    data = as.data.frame(data)
-  )
-  #
-  # Return result
-  oldClass(result) <- "mads"
-  result
+    data = as.data.frame(data))
+  return(result)
 }
 
 
