@@ -1,7 +1,7 @@
-barnard.rubin <- function(m, b, t, dfcom = 999999) {
+barnard.rubin <- function(m, b, t, dfcom = Inf) {
   lambda <- (1 + 1 / m) * b / t
   lambda[lambda < 1e-04] <- 1e-04
   dfold <- (m - 1) / lambda^2
   dfobs <- (dfcom + 1) / (dfcom + 3) * dfcom * (1 - lambda)
-  dfold * dfobs / (dfold + dfobs)
+  ifelse(is.infinite(dfcom), dfold, dfold * dfobs / (dfold + dfobs))
 }
