@@ -20,6 +20,10 @@
 #' always be an object of class \code{mild}. Setting \code{mild = TRUE}
 #' overrides \code{action} keywords \code{"long"}, \code{"broad"}
 #' and \code{"repeated"}. The default is \code{FALSE}.
+#' @param order Either \code{"first"} or \code{"last"}. Only relevant when
+#' \code{action == "long"}. Writes the \code{".imp"} and \code{".id"}
+#' in columns 1 and 2. The default is \code{order = "last"}.
+#' Included for backward compatibility with \code{"< mice 3.16.0"}.
 #' @param \dots Additional arguments. Not used.
 #' @return Complete data set with missing values replaced by imputations.
 #' A \code{data.frame}, or a list of data frames of class \code{mild}.
@@ -77,8 +81,10 @@
 #' names(dslist)
 #' @export
 complete.mids <- function(data, action = 1L, include = FALSE,
-                          mild = FALSE, ...) {
+                          mild = FALSE, order = c("last", "first"),
+                          ...) {
   if (!is.mids(data)) stop("'data' not of class 'mids'")
+  order <- match.arg(order)
 
   m <- as.integer(data$m)
   if (is.numeric(action)) {
@@ -108,13 +114,16 @@ complete.mids <- function(data, action = 1L, include = FALSE,
     return(mylist)
   }
   if (shape == "long") {
-    cmp <- bind_rows(mylist)
-    cmp <- data.frame(
-      .imp = rep(idx, each = nrow(data$data)),
-      .id = rep.int(1L:nrow(data$data), length(idx)),
-      cmp
-    )
-    if (is.integer(attr(data$data, "row.names"))) {
+    cmp <- mylist %>%
+      bind_rows() %>%
+      mutate(
+        .imp = rep(idx, each = nrow(data$data)),
+        .id = rep.int(attr(data$data, "row.names"), length(idx)),
+      )
+    if (order == "first") {
+      cmp <- relocate(cmp, any_of(c(".imp", ".id")))
+    }
+    if (typeof(attr(data$data, "row.names")) == "integer") {
       row.names(cmp) <- seq_len(nrow(cmp))
     } else {
       row.names(cmp) <- as.character(seq_len(nrow(cmp)))
@@ -124,8 +133,8 @@ complete.mids <- function(data, action = 1L, include = FALSE,
   # must be broad or repeated
   cmp <- bind_cols(mylist)
   names(cmp) <- paste(rep.int(names(data$data), m),
-    rep.int(idx, rep.int(ncol(data$data), length(idx))),
-    sep = "."
+                      rep.int(idx, rep.int(ncol(data$data), length(idx))),
+                      sep = "."
   )
   if (shape == "broad") {
     return(cmp)
@@ -146,7 +155,13 @@ single.complete <- function(data, where, imp, ell) {
     if (is.null(imp[[j]])) {
       data[where[, j], j] <- NA
     } else {
-      data[where[, j], j] <- imp[[j]][, ell]
+      if (sum(where[, j]) == nrow(imp[[j]])) {
+        # assume equal length
+        data[where[, j], j] <- imp[[j]][, ell]
+      } else {
+        # index by rowname
+        data[as.numeric(rownames(imp[[j]])), j] <- imp[[j]][, ell]
+      }
     }
   }
   data
