@@ -2,15 +2,16 @@ context("mice.mids: newdata")
 
 # Check that mice.mids correctly appends the newdata to the
 # existing mids object
-# Outcomment: This test depends on side effect of the global
-# random generator. Does not work anymore using withr::local_seed()
-#init0 <- mice(nhanes, maxit = 0, m = 1, print = FALSE, seed = 1)
-#init1 <- mice(nhanes, maxit = 0, m = 1, print = FALSE)
-#init1$ignore <- rep(FALSE, nrow(nhanes))
-#init2 <- mice.mids(init0, newdata = nhanes, maxit = 0, print = FALSE)
-#test_that("`newdata` works like rbind with ignore", {
-#  expect_equal(complete(rbind(init0, init1)), complete(init2))
-#})
+init0 <- mice(nhanes, maxit = 0, m = 1, print = FALSE, seed = 1)
+
+init1 <- mice(nhanes, maxit = 0, m = 1, print = FALSE)
+init1$ignore <- rep(FALSE, nrow(nhanes))
+
+init2 <- mice.mids(init0, newdata = nhanes, maxit = 0, print = FALSE)
+
+test_that("`newdata` works like rbind with ignore", {
+  expect_equal(complete(rbind(init0, init1)), complete(init2))
+})
 
 imp <- mice(nhanes2, maxit = 0, m = 1, seed = 1)
 test_that("`newdata` produces warning `invalid factor level, NA generated`", {
@@ -47,5 +48,3 @@ test_that("`newdata` returns filtered mids object", {
 test_that("`newdata` uses a common seed", {
   expect_true(identical(complete(imp2), complete(imp2b)))
 })
-
-
