@@ -6,7 +6,7 @@ context("pool")
 # FIXME: consider using the new generator once V3.6.0 is out,
 # at the expense of breaking reproducibility of the examples in
 # https://stefvanbuuren.name/fimd/
-# suppressWarnings(RNGversion("3.5.0"))
+suppressWarnings(RNGversion("3.5.0"))
 
 imp <- mice(nhanes2, print = FALSE, maxit = 2, seed = 121, use.matcher = TRUE)
 fit <- with(imp, lm(bmi ~ chl + age + hyp))
@@ -14,12 +14,16 @@ est <- pool(fit)
 # fitlist <- fit$analyses
 # est <- mice:::pool.fitlist(fitlist)
 
-mn <- c(19.7878, 0.0513, -6.1563, -7.7136, 2.9521)
-se <- c(3.4259, 0.0187, 1.6195, 1.9746, 1.8642)
+mn <- c(18.76175, 0.05359003, -4.573652, -6.635969, 2.163629)
+se <- c(4.002796, 0.02235067, 2.033986, 2.459769, 2.02898)
+
+test_that("summary(est) works", {
+  expect_is(summary(est), "data.frame")
+})
 
 test_that("retains same numerical result", {
-  expect_equal(unname(getqbar(est)), mn, tolerance = 0.0001)
-  expect_equal(unname(summary(est)[, "std.error"]), se, tolerance = 0.0001)
+  expect_equal(unname(getqbar(est)), mn, tolerance = 0.00001)
+  expect_equal(unname(summary(est)[, "std.error"]), se, tolerance = 0.00001)
 })
 
 
@@ -167,4 +171,3 @@ mitml::testModels(fit1, fit0, method = "D3")
 # ---
 
 fit1 <- with(implist, lmer(ReadAchiev ~ ReadDis + SES + (1 | ID), REML = FALSE))
-
